@@ -90,58 +90,3 @@ fn compute_best_dash_1_2_5(one_step: f64, ideal_dash_size: f64, normalized_step:
         _ => unreachable!(),
     }
 }
-
-///
-/// Create a [`plotnum::TickDist`] from a step iterator.
-///
-pub fn steps<
-    X: PlotNum,
-    I: Iterator<Item = X>,
-    F: FnMut(&mut dyn fmt::Write, &X) -> fmt::Result,
->(
-    bound: Bound<X>,
-    steps: I,
-    func: F,
-) -> plotnum::TickDist<num::StepFmt<X, F>> {
-    let ticks: Vec<_> = steps
-        .skip_while(|&x| x < bound.min)
-        .take_while(|&x| x <= bound.max)
-        .map(|x| Tick {
-            value: x,
-            position: x,
-        })
-        .collect();
-
-    assert!(
-        ticks.len() >= 2,
-        "Atleast two ticks must be created for the given data range."
-    );
-
-    TickDist {
-        ticks: TickInfo {
-            bound,
-            ticks,
-            dash_size: None,
-            display_relative: None,
-        },
-        fmt: StepFmt {
-            func,
-            _p: PhantomData,
-        },
-    }
-}
-
-pub struct StepFmt<J, F> {
-    func: F,
-    _p: PhantomData<J>,
-}
-impl<J: PlotNum, F: FnMut(&mut dyn fmt::Write, &J) -> fmt::Result> TickFormat for StepFmt<J, F> {
-    type Num = J;
-    fn write_tick(
-        &mut self,
-        writer: &mut dyn std::fmt::Write,
-        val: &Self::Num,
-    ) -> std::fmt::Result {
-        (self.func)(writer, val)
-    }
-}
